@@ -10,6 +10,6 @@ import pytest
 
 @pytest.mark.sphinx('html', testroot='citationnotfound')
 def test_citationnotfound(app, warning):
-    app.builder.build_all()
+    app.build()
     assert 'could not find bibtex key nosuchkey1' in warning.getvalue()
     assert 'could not find bibtex key nosuchkey2' in warning.getvalue()
