@@ -5,7 +5,7 @@ import pytest
 # see issue 87
 @pytest.mark.sphinx('html', testroot='key_prefix')
 def test_key_prefix(app, warning):
-    app.builder.build_all()
+    app.build()
     assert not warning.getvalue()
     output = (app.outdir / "doc0.html").read_text()
     cits = {match.group('label')
